"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const BaseCommand_1 = require("../../application/BaseCommand");
class MakeSchemas extends BaseCommand_1.default {
    constructor() {
        super(...arguments);
        this.signature = 'make:schemas';
        this.configKey = 'make.schemas';
    }
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            this.logger.comet('Generating JSON schema files...');
            const { args, flags } = this.parse(MakeSchemas);
            const file = yield this.loadFile(args);
            if (flags.output) {
                this.configRepository.set(`commands.${this.configKey}.output`, flags.output);
            }
            const specification = yield this.parseSpec(file);
            yield this.execute(specification);
        });
    }
    execute(specification) {
        return __awaiter(this, void 0, void 0, function* () {
            this.logger.spin('Creating JSON Schemas...');
            yield this.runDecorators(specification);
            yield this.runFactories(specification);
            this.logger.succeed('JSON Schemas created');
        });
    }
}
MakeSchemas.description = 'Parse an API specification, and automatically generate JSON schemas';
MakeSchemas.examples = [
    '$ comet make:schemas api.json',
];
MakeSchemas.args = [
    {
        name: 'input',
        required: true,
        description: 'relative or absolute path to the input file (your API specification)',
    },
];
MakeSchemas.flags = {
    help: command_1.flags.help({ char: 'h' }),
    output: command_1.flags.string({
        char: 'o',
    }),
};
exports.default = MakeSchemas;
//# sourceMappingURL=schemas.js.map